.pvtUi{border-collapse:collapse;color:#2a3f5f;font-family:Verdana}.pvtUi select{user-select:none;-webkit-user-select:none;-moz-user-select:none;-khtml-user-select:none;-ms-user-select:none}.pvtUi td.pvtOutput{vertical-align:top}table.pvtTable{border-collapse:collapse;font-family:Verdana;font-size:8pt;margin-left:3px;margin-top:3px;text-align:left}table.pvtTable tbody tr th,table.pvtTable thead tr th{background-color:#ebf0f8;border:1px solid #c8d4e3;font-size:8pt;padding:5px}table.pvtTable .pvtColLabel{text-align:center}table.pvtTable .pvtTotalLabel{text-align:right}table.pvtTable tbody tr td{background-color:#fff;border:1px solid #c8d4e3;color:#2a3f5f;padding:5px;text-align:right;vertical-align:top}.pvtGrandTotal,.pvtTotal{font-weight:700}.pvtColOrder,.pvtRowOrder{cursor:pointer;display:inline-block;margin-left:5px;text-decoration:none!important;user-select:none;-webkit-user-select:none;-moz-user-select:none;-khtml-user-select:none;-ms-user-select:none;width:15px}.pvtAxisContainer,.pvtVals{background:#f2f5fa;border:1px solid #a2b1c6;min-height:20px;min-width:20px;padding:5px}.pvtRenderers{padding-left:5px;-webkit-user-select:none;user-select:none}.pvtDropdown{display:inline-block;margin:3px;position:relative;-webkit-user-select:none;-moz-user-select:none;-khtml-user-select:none;-ms-user-select:none}.pvtDropdownIcon{color:#a2b1c6;float:right}.pvtDropdownCurrent{background:#fff;border:1px solid #a2b1c6;border-radius:4px;box-sizing:border-box;display:inline-block;position:relative;text-align:left;width:210px}.pvtDropdownCurrentOpen{border-radius:4px 4px 0 0}.pvtDropdownMenu{background:#fff;border:1px solid #a2b1c6;border-radius:0 0 4px 4px;border-top-color:#dfe8f3;box-sizing:border-box;margin-top:-1px;position:absolute;width:100%}.pvtDropdownValue{font-size:12px;padding:2px 5px;text-align:left}.pvtDropdownActiveValue{background:#ebf0f8}.pvtVals{padding-bottom:12px;text-align:center;vertical-align:top;white-space:nowrap}.pvtRows{height:35px}.pvtAxisContainer li{cursor:move;list-style-type:none;padding:8px 6px}.pvtAxisContainer li.pvtPlaceholder{border:1px dashed #a2b1c6;-webkit-border-radius:5px;border-radius:5px;padding:3px 15px}.pvtAxisContainer li.pvtPlaceholder span.pvtAttr{display:none}.pvtAxisContainer li span.pvtAttr{-webkit-text-size-adjust:100%;background:#f3f6fa;border:1px solid #c8d4e3;border-radius:5px;padding:2px 5px;user-select:none;-webkit-user-select:none;-moz-user-select:none;-khtml-user-select:none;-ms-user-select:none;white-space:nowrap}.pvtTriangle{color:#506784;cursor:pointer}.pvtHorizList li{display:inline-block}.pvtVertList{vertical-align:top}.pvtFilteredAttribute{font-style:italic}.sortable-chosen .pvtFilterBox{display:none!important}.pvtCloseX{cursor:pointer;right:5px;text-decoration:none!important}.pvtCloseX,.pvtDragHandle{font-size:18px;position:absolute;top:5px}.pvtDragHandle{color:#a2b1c6;cursor:move;left:5px}.pvtButton{background:#f2f5fa;border:1px solid #c8d4e3;border-radius:5px;color:#506784;font-size:14px;margin:3px;padding:3px 6px;text-decoration:none!important;transition:all .34s cubic-bezier(.19,1,.22,1)}.pvtButton:hover{background:#e2e8f0;border-color:#a2b1c6}.pvtButton:active{background:#d1dae6}.pvtFilterBox input{border:1px solid #c8d4e3;border-radius:5px;color:#506784;font-size:14px;padding:0 3px}.pvtFilterBox input:focus{border-color:#119dff;outline:none}.pvtFilterBox{background-color:#fff;border:1px solid #506784;min-height:100px;position:absolute;text-align:center;user-select:none;-webkit-user-select:none;-moz-user-select:none;-khtml-user-select:none;-ms-user-select:none;width:300px;z-index:100}.pvtFilterBox h4{margin:15px}.pvtFilterBox p{margin:10px auto}.pvtFilterBox button{color:#2a3f5f}.pvtFilterBox input[type=text]{color:#2a3f5f;margin-bottom:5px;width:230px}.pvtCheckContainer{border-top:1px solid #dfe8f3;font-size:14px;max-height:30vh;overflow-y:scroll;text-align:left;white-space:nowrap;width:100%}.pvtCheckContainer p{cursor:default;margin:0 0 1px;padding:3px}.pvtCheckContainer p.selected{background:#ebf0f8}.pvtOnly{cursor:pointer;display:none;float:left;font-size:12px;padding-left:5px;width:35px}.pvtOnlySpacer{display:block;float:left;width:35px}.pvtCheckContainer p:hover .pvtOnly{display:block}.pvtCheckContainer p:hover .pvtOnlySpacer{display:none}.pvtRendererArea{padding:5px}
/*# sourceMappingURL=main.fd21f2e2.css.map*/